@@ -1,13 +1,13 @@
 #!/bin/sh
 echo 'name: directory-tree
-version: 0.10.0
-id: directory-tree-0.10.0-361c608061f82ee09b9bf88ef9fd8c4b
+version: 0.11.0
+id: directory-tree-0.11.0-0f25d13869a5d7392e7d0db657bc695a
 
 license: BSD3
 copyright: (c) 2011, Brandon Simmons <brandon.m.simmons@gmail.com>
 maintainer: Brandon Simmons <brandon.m.simmons@gmail.com>
 stability:
-homepage: http://coder.bsimmons.name/blog/2009/05/directory-tree-module-released/
+homepage: http://brandon.si/code/directory-tree-module-released/
 package-url:
 synopsis: A simple directory-like tree datatype, with useful IO functions
 description: A simple directory-like tree datatype, with useful IO functions and Foldable and Traversable instance
@@ -59,6 +59,16 @@ description: A simple directory-like tree datatype, with useful IO functions and
              .
              Any ideas or suggestions for improvements are most welcome :-)
              .
+             /CHANGES/: from 0.10.1
+             .
+             - added records for AnchoredDirTree: '\''anchor'\'', '\''dirTree'\''
+             .
+             - '\''free'\'' deprecated in favor of '\''dirTree'\''
+             .
+             - added a new function '\''dropTo'\''
+             .
+             - implemented lenses compatible with "lens" package
+             .
 category: Data, System
 author: Brandon Simmons
 pkgpath: devel/hs-directory-tree
@@ -66,21 +76,21 @@ exposed: True
 exposed-modules: System.Directory.Tree
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/directory-tree-0.10.0
-library-dirs: /usr/local/lib/ghc/directory-tree-0.10.0
-hs-libraries: HSdirectory-tree-0.10.0
+import-dirs: /usr/local/lib/ghc/directory-tree-0.11.0
+library-dirs: /usr/local/lib/ghc/directory-tree-0.11.0
+hs-libraries: HSdirectory-tree-0.11.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         directory-1.1.0.2-da0a8c62c2b42ae7a3b538f5fee58422
-         filepath-1.3.0.0-f998e5510c76a98913f57b14b4f16c57
+depends: base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
+         directory-1.2.0.1-5cea89dab5fade71d74e1fcf13ee5ca4
+         filepath-1.3.0.1-edbc3d8247914b04f448e9261e7fe895
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-directory-tree-0.10.0/html/directory-tree.haddock
-haddock-html: /usr/local/share/doc/hs-directory-tree-0.10.0/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-directory-tree-0.11.0/html/directory-tree.haddock
+haddock-html: /usr/local/share/doc/hs-directory-tree-0.11.0/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
